## 版本说明

| 版本号 | 版本信息            | 发布日期  |
| ------ | ------------------- | --------- |
| 0.0.1  | 项目初始化          | 2022-4-19 |
| 0.0.2  | 添加基础库          | 2022-4-21 |
| 0.0.3  | 增加matplotlib和ocr | 2022-4-24 |

> 关于版本更新，如有疑问，请私信微博@[程序员晚枫](http://www.python4office.cn/weibo-qaq/)

## 参考资料 
- 关于setup.py的参数说明
    - https://packaging.python.org/en/latest/guides/distributing-packages-using-setuptools/#install-requires
- 如何使用setup.cfg
    - https://zhuanlan.zhihu.com/p/261579357